@@ -57,7 +57,7 @@ AS = {
     "args": {},
     "wifi-connected": False,
     "defaults": {
-        # "config_file": "SPR-defaults.yaml",
+        "config_file": "SPR-config.yaml",
         "loglevel": "info",
         "logfile": "SPR.log",
     },
@@ -593,8 +593,10 @@ def load_functions():
     # fns = get_in_config(['exec', 'functions'])
     # print(yaml.dump(fns))
 
-    for k, v in get_in_config(["exec", "functions"]).items():
-        r.add_symbol(k, v["fn"], v["doc"])
+    fns = get_in_config(["exec", "functions"])
+    if fns is not None:
+        for k, v in fns.items():
+            r.add_symbol(k, v["fn"], v["doc"])
 
 
 def save_yaml_file(filename, dictionary):
@@ -605,36 +607,37 @@ def save_yaml_file(filename, dictionary):
 
 def load_yaml_file(filename):
     "load a dictionary from a yaml file"
-    with open(filename) as f:
-        someyaml = yaml.load(f, Loader=yaml.SafeLoader)
-    return someyaml
+    if os.path.isfile(filename):
+        logger.info("Loading Configuration: %s" % filename)
+        with open(filename) as f:
+            someyaml = yaml.load(f, Loader=yaml.SafeLoader)
+        return someyaml
 
 
-def load_defaults(pkgname=None, yamlname=None):
+def load_defaults(state_init, pkgname=None, yamlname=None):
     global AS
 
     AS["config"] |= load_base_config()
+    AS |= state_init
     if pkgname is None:
         return AS
     AS["config"] |= load_pkg_config(pkgname, yamlname)
     return AS
 
 
-import pkg_resources
-
-# DATA_PATH = pkg_resources.resource_filename("<package name>", "data/")
-# DB_FILE = pkg_resources.resource_filename("<package name>", "data/sqlite.db")
-
-
+# import pkg_resources
 def load_pkg_config(pkgname, yamlname):
-    # return yaml.load(pkgutil.get_data(pkgname, yamlname), Loader=yaml.SafeLoader)
-    f = pkg_resources.resource_filename(pkgname, yamlname)
+    """load a configuration file from a package."""
+    logger.info("Loading Configuration: %s: %s" % (pkgname, yamlname))
+    return yaml.load(pkgutil.get_data(pkgname, yamlname), Loader=yaml.SafeLoader)
+    # f = pkg_resources.resource_filename(pkgname, yamlname)
     # print(f)
     # print(load_yaml_file(f))
-    return load_yaml_file(f)
+    # return load_yaml_file(f)
 
 
 def load_base_config():
+    """load the default configuration."""
     return load_pkg_config(__name__, "SPR-defaults.yaml")
 
 
@@ -736,7 +739,7 @@ def do_something():
 
     # Run the repl.
     if AS["args"]["repl"]:
-        r.repl(get_in_config)(["REPL", "prompt"])
+        r.repl(get_in_config(["REPL", "prompt"]))
 
     # if there aren't any commands on the cli
     # do the auto exec in a loop or once.
@@ -795,12 +798,16 @@ def init(symbols, specials, parser):
 
     AS["args"] = vars(parser.parse_args())
 
-    if AS["args"]["config_file"]:
-        AS["config"] |= load_yaml_file(AS["args"]["config_file"])
+    if get_in(AS, ["args" "config_file"]):
+        y = load_yaml_file(AS["args"]["config_file"])
+        if y is not None:
+            AS["config"] |= y
     elif get_in(AS, ["defaults", "config_file"]):
-        AS["config"] |= load_yaml_file(get_in(AS, ["defaults", "config_file"]))
+        y = load_yaml_file(get_in(AS, ["defaults", "config_file"]))
+        if y is not None:
+            AS["config"] |= y
 
-    print(get_in_config(["files", "loglevel"]))
+    # print(get_in_config(["files", "loglevel"]))
 
     logs.add_file_handler(
         logger,
